@@ -20,14 +20,15 @@ macro_rules! implement_cron {
             payload: Payload,
             scheduling_interval: ic_cron::types::SchedulingInterval,
         ) -> ic_cdk::export::candid::Result<ic_cron::types::TaskId> {
-            let id = get_cron_state().enqueue(
-                kind,
-                payload,
-                scheduling_interval,
-                ic_cdk::api::time(),
-            )?;
+            let cron = get_cron_state();
 
-            _call_cron_pulse();
+            let id = cron.enqueue(kind, payload, scheduling_interval, ic_cdk::api::time())?;
+
+            if !cron.is_running {
+                cron.try_start();
+
+                _call_cron_pulse();
+            }
 
             Ok(id)
         }
