@@ -117,8 +117,6 @@ impl TaskScheduler {
             }
         }
 
-        self.try_stop();
-
         tasks
     }
 
@@ -149,7 +147,7 @@ impl TaskScheduler {
         res
     }
 
-    fn try_start(&mut self) -> bool {
+    pub fn try_start(&mut self) -> bool {
         if !self.is_running {
             self.is_running = true;
 
@@ -159,7 +157,7 @@ impl TaskScheduler {
         }
     }
 
-    fn try_stop(&mut self) -> bool {
+    pub fn try_stop(&mut self) -> bool {
         if !self.is_running {
             true
         } else if self.tasks.is_empty() {
